HACKER ANGELWHITE GALC

miércoles, 3 de junio de 2020

Esta es la herramienta avanzada de phishing! OTP PHISHING




20200316_174935_0000

TÉCNICA

Cuando la víctima ingresa sus credenciales, debe ir al sitio web original y usar esas credenciales para enviar OTP real a la víctima. Una vez que ingrese esa OTP, dicha OTP también estará allí con usted y se le permitirá iniciar sesión en la cuenta antes que él.


TUTORIAL [TERMUX]

(des

Captura de pantalla (Kali)

76759776-be934580-6762-11ea-922d-711dfdd19584

INSTALACIÓN [APLICACIÓN TERMUX --ANDROID]

INSTALACIÓN [KALI]

OPCIONES DE TÚNELIZACIÓN DISPONIBLES

  1. LOCALHOST
  2. NGROK ( https://ngrok.com/ )

PROBADO EN LO SIGUIENTE: -

  • Kali Linux - 2020.1a (versión)
  • Parrot OS - Rolling Edition (versión)
  • Ubuntu - 18.04 (versión)
  • Arch Linux
  • Aplicación Termux

REQUISITOS PREVIOS

  • sudo - [DEBE]
  • php
  • apache2
  • Token ngrok

IDIOMA

 

 

Crea tu propia BotNet con Byob






Ver las imágenes de origenActualizado 2020 Cómo construir su propio malware de botnet:
Está diseñado para permitir a los desarrolladores implementar fácilmente su propio código y agregar nuevas características interesantes sin tener que escribir una RAT (Herramienta de administración remota) o un C2 (Servidor de comando y control) desde cero.

> La característica clave de la RAT es que los códigos / archivos arbitrarios pueden cargarse de forma remota en la memoria desde el C2 y ejecutarse en la máquina de destino sin escribir nada en el disco compatible con python 2 y 3
twitter.com/undercodenews

Cómo construir ?

1) Genere clientes completamente indetectables con cargas útiles por etapas, importaciones remotas y módulos ilimitados de post explotación

2) Importaciones remotas: importe de forma remota paquetes de terceros desde el servidor sin escribirlos en el disco o descargarlos / instalarlos
Nada escrito en el disco: los clientes nunca escriben nada en el disco, ni siquiera archivos temporales (se realizan cero llamadas al sistema de E / S) porque las importaciones remotas permiten que el código arbitrario se cargue dinámicamente en la memoria y se importe directamente en el proceso actualmente en ejecución

3) Cero dependencias (ni siquiera Python en sí): el cliente se ejecuta solo con la biblioteca estándar de Python, importa de forma remota cualquier paquete / módulo no estándar desde el servidor y se puede compilar con un intérprete de Python independiente en un ejecutable binario portátil formateado para cualquier plataforma / arquitectura, lo que le permite ejecutarse en cualquier cosa, incluso cuando falta Python en el host de destino

4) Agregue nuevas funciones con solo 1 clic: cualquier script, módulo o paquete de Python que copie en el directorio ./byob/modules/ automáticamente se puede importar de forma remota y puede ser utilizado directamente por cada cliente mientras su servidor de comando y control se está ejecutando

5) Escriba sus propios módulos: se proporciona una plantilla básica de módulo en el directorio ./byob/modules/ para que escribir sus propios módulos sea un proceso sencillo y sin complicaciones

6) Ejecute módulos ilimitados sin aumentar el tamaño del archivo: use las importaciones remotas para agregar funciones ilimitadas sin agregar un solo byte al tamaño del archivo del cliente

7) Totalmente actualizable: cada cliente verificará periódicamente el servidor en busca de nuevo contenido disponible para la importación remota y actualizará dinámicamente sus recursos en memoria si se ha agregado / eliminado algo

8) Plataforma independiente: todo está escrito en Python (un lenguaje independiente de la plataforma) y los clientes generados pueden compilarse opcionalmente en un ejecutable portátil (Windows) o agruparse en una aplicación independiente (macOS)

9) Evitar los firewalls: los clientes se conectan al servidor de comando y control a través de conexiones TCP inversas, lo que evitará la mayoría de los firewalls porque las configuraciones de filtro predeterminadas bloquean principalmente las conexiones entrantes

10) Contramedida contra antivirus: evita ser analizado por antivirus al bloquear los procesos con nombres de productos antivirus conocidos para que no se reproduzcan

11) Cifrar cargas útiles para evitar el análisis: la carga útil principal del cliente se cifra con una clave aleatoria de 256 bits que existe únicamente en el generador de carga útil que se genera junto con ella

12) Prevención de ingeniería inversa: de forma predeterminada, los clientes suspenderán la ejecución si se detecta una máquina virtual o sandbox

MÓDULOS
1) Módulos posteriores a la explotación que los clientes pueden importar de forma remota

2) Keylogger (byob.modules.keylogger): registra las pulsaciones de teclas del usuario y el nombre de la ventana ingresada

3) Captura de pantalla (byob.modules.screenshot): tome una captura de pantalla del escritorio del usuario actual

4) Cámara web (byob.modules.webcam): vea una transmisión en vivo o capture imágenes / videos desde la cámara web

5) Ransom (byob.modules.ransom): encripta archivos y genera una billetera BTC aleatoria para el pago del rescate

6) Outlook (byob.modules.outlook): leer / buscar / cargar correos electrónicos desde el cliente local de Outlook

7) Sniffer de paquetes (byob.modules.packetsniffer): ejecute un sniffer de paquetes en la red host y cargue el archivo .pcap

8) Persistencia (byob.modules.persistence): establezca la persistencia en la máquina host utilizando 5 métodos diferentes

9) Teléfono (byob.modules.phone): leer / buscar / cargar mensajes de texto desde el teléfono inteligente del cliente

10) Escalar privilegios (byob.modules.escalate): intente la omisión de UAC para obtener privilegios de administrador no autorizados

> construir malware parte 2

11) Port Scanner (byob.modules.portscanner): escanea la red local en busca de otros dispositivos en línea y puertos abiertos

12) Control de procesos (byob.modules.process): enumerar / buscar / matar / supervisar los procesos que se ejecutan actualmente en el host

13) iCloud (byob.modules.icloud): verifique la cuenta de iCloud registrada en macOS

14) Spreader (byob.modules.spreader): distribuye el cliente a otros hosts a través de correos electrónicos disfrazados de actualización de complemento

15) Minero (byob.modules.miner): ejecute un minero de criptomonedas en segundo plano (admite Bitcoin y Litecoi

> https://github.com/malwaredllc/byob echa un vistazo a estos módulos de código


findom-xss: escáner rápido de vulnerabilidades XSS basado en DOM

FinDOM-XSS

FinDOM-XSS es una herramienta que le permite encontrar la vulnerabilidad XSS basada en DOM posible y / potencial de una manera rápida.
 
 

Instalación

$ git clone git@github.com: dwisiswant0 / findom-xss.git

Configuración

Cambiar el valor de la variable  LINKFINDER  (en la línea 3) con su archivo principal de LinkFinder.

Uso

Para ejecutar la herramienta en un objetivo, simplemente use el siguiente comando.
$ ./findom-xss.sh https://target.host/about-us.html
Esto ejecutará la herramienta contra target.host . O si tiene una lista de objetivos que desea escanear.
$ cat urls.txt | xargs -I% ./findom-xss.sh%
El segundo argumento puede usarse para especificar un archivo de salida.
$ ./findom-xss.sh https://target.host/about-us.html /path/to/output.txt
Por defecto, la salida se almacenará en el directorio results / en el repositorio con el  nombre target.host.txt .

EagleEye: Herramienta de reconocimiento de imagen [FB, YT, Instagram, Twitter]





EagleEye: Herramienta de reconocimiento de imagen [FB, YT, Instagram, Twitter]


EagleEye es una herramienta de reconocimiento de imágenes que le permite rastrear a la persona a través de las redes sociales. Todo lo que necesita es al menos una imagen de alguien para quien está buscando y un nombre o una pequeña pista sobre el nombre de esa persona. Cuando ingrese estos datos en EagleEye, intentará encontrar los perfiles y las cuentas en Facebook, YouTube, Twitter e Instagram relacionados con la persona buscada.

EagleEye: Reconocimiento de imágenes y herramienta de búsqueda inversa de imágenes

EagleEye básicamente realiza reconocimiento facial o de imagen sobre la imagen proporcionada. Cuando ingresa los datos, como el nombre y la imagen de una persona con reconocimiento de imagen, también coincide con el nombre en las redes sociales como Facebook, YouTube, Twitter e Instagram. Cuando encuentra resultados relevantes en el tipo de perfiles de usuario, muestra estos resultados a su usuario. También puede buscar a través de perfiles seguros y ocultos de personas en las redes sociales.
Si EagleEye encuentra algún perfil, por ejemplo, uno de Facebook, comparará las imágenes de perfil con las imágenes dadas. Después de verificar los datos, proporcionará un informe en pdf.

caracteristicas:

  • Reconocimiento de imagen | Reconocimiento facial | Facebook | YouTube | Instagram | Gorjeo

Plataformas compatibles:

  • Linux

Requisitos:

General:

  • Un sistema con Linux que tiene x-server
  • Firefox instalado

Sin estibador:

  • Python 3.6+
  • Pepita de Python

Con Docker:

  • Solo acoplador

Instalar EagleEye

Docker (preferido)

Confirme que ha instalado docker en su sistema y que está utilizando la distribución de Linux como un host.
Clonar el repositorio:
$ git clone https://github.com/ThoughtfulDev/EagleEye
$ cd EagleEye 
$ sudo docker build -t ojo de águila - <dockerfile 
- Después de eso, cree dos carpetas con el nombre knowny resulten su computadora.
- Luego, asegúrese de agregar imágenes de personas conocidas en la carpeta con el nombre known.
- Asegúrese de haber cambiado el nombre de la persona que busca en entry.sh
- Comience el contenedor. Edite los caminos:
$ sudo docker run -t --net = host --env = "DISPLAY" \
                           --volume = "$ HOME / .Xauthority: /root/.Xauthority: rw" \
                           -v / ruta / a / conocido: / EagleEye / conocido \
                           -v / ruta / a / resultado: / resultado \
                           -v /path/to/EagleEye/Repository/entry.sh:/entry.sh \
                           ojo de águila
Los resultados se mostrarán en /path/to/result.

Instalación de requisitos previos automatizados

Si la ventana acoplable no funciona, puede ejecutar la instalación automática de requisitos previos:
wget https://raw.githubusercontent.com/ThoughtfulDev/EagleEye/master/install.sh && chmod + x install.sh && ./install.sh

Prerrequisitos manuales Instalación

Distros basados ​​en Debian

$ sudo apt update && sudo apt upgrade -y
$ sudo apt install git python3 python3-pip python3-dev
$ sudo apt install libgtk-3-dev libboost-all-dev build-essential cmake libffi-dev
$ git clone https://github.com/ThoughtfulDev/EagleEye
$ cd EagleEye && sudo pip3 install -r require.txt
$ sudo pip3 install --upgrade beautifulsoup4 html5lib spry

Arch Linux

$ sudo pacman -Syu
$ sudo pacman -S git python python-pip gtk3 boost cmake libffi
$ git clone https://github.com/ThoughtfulDev/EagleEye
$ cd EagleEye && sudo pip3 install -r require.txt
$ sudo pip3 install --upgrade beautifulsoup4 html5lib spry

Configuración EagleEye


- Cambie el valor en  config.json la ruta de la  geckodriver.
- Coloque al menos una imagen de la persona que desea encontrar en la  known carpeta.

Uso

$ python3 eagle-eye.py
Para enumerar todas las opciones disponibles, use -h:
$ python3 eagle-eye.py -h
Descarga https://github.com/ThoughtfulDev/EagleEye
Grupo de Telegram: https://t.me/hackingteamelrinconoscuro

Canal de Youtube: https://www.youtube.com/channel/UCXy8Lg28OuGuI5Z-2EWJaNA?view_as=subscriber

Canal Vimeo: https://vimeo.com/403136547?activityReferer=1

Red Social Twitter: https://twitter.com/HackingTeam1?s=09

Pagina Web: https://elrincondehackingteam.blogspot.com/

sábado, 19 de enero de 2019

Information gathering & OSINT reconnaissance tool for phone numbers.
One of the most advanced tools to scan phone numbers using only free resources. The goal is to first gather basic information such as country, area, carrier and line type on any international phone numbers with a very good accuracy. Then try to determine the VoIP provider or search for footprints on search engines to try identify the owner.

OSINT Tutorial: Building an OSINT Reconnaissance Tool from Scratch

para descargar: https://github.com/sundowndev/PhoneInfoga.git

Features

  • Check if phone number exists and is possible
  • Gather standard informations such as country, line type and carrier
  • Check several numbers at once
  • OSINT reconnaissance using external APIs, Google Hacking, phone books & search engines
  • Use custom formatting for more effective OSINT reconnaissance

Formats

The tool only accepts E164 and International formats as input.
  • E164: +3396360XXXX
  • International: +33 9 63 60 XX XX
  • National: 09 63 60 XX XX
  • RFC3966: tel:+33-9-63-60-XX-XX
  • Out-of-country format from US: 011 33 9 63 60 XX XX

Available scanners

Use any to disable this feature. Default value: all
  • numverify
  • ovh

Installation

git clone https://github.com/sundowndev/PhoneInfoga
cd PhoneInfoga/
python3 -m pip install -r requirements.txt

Usage

usage: phoneinfoga.py -n <number> [options]

Advanced information gathering tool for phone numbers
(https://github.com/sundowndev/PhoneInfoga)

optional arguments:
  -h, --help            show this help message and exit
  -n number, --number number
                        The phone number to scan (E164 or International
                        format)
  -i input_file, --input input_file
                        Phone number list to scan (one per line)
  -o output_file, --output output_file
                        Output to save scan results
  -s scanner, --scanner scanner (any to skip, default: all)
                        The scanner to use
  --osint               Use OSINT reconnaissance
  -u, --update          Update the tool & databases
Example (quotes are optional, use it when typing special formats) :
python3 phoneinfoga.py -n "(+42)837544833"
Check for a number range on OVH :
python3 phoneinfoga.py -n +42837544833 -s ovh
Check several numbers at once :
python3 phoneinfoga.py -i numbers.txt -o results.txt
Note: --osint is not compatible with --output option.
Use all scanners and run OSINT reconnaissance :
python3 phoneinfoga.py -n +42837544833 -s all --osint

Formatting

E.164 formatting for phone numbers entails the following:
  • A + (plus) sign
  • International Country Calling code
  • Local Area code
  • Local Phone number
For example, here’s a US-based number in standard local formatting: (415) 555-2671
Here’s the same phone number in E.164 formatting: +14155552671
In the UK, and many other countries internationally, local dialing may require the addition of a '0' in front of the subscriber number. With E.164 formatting, this '0' must usually be removed.
For example, here’s a UK-based number in standard local formatting: 020 7183 8750
Here’s the same phone number in E.164 formatting: +442071838750

Dealing with Google captcha

PhoneInfo use a workaround to handle Google bot detection. When running OSINT scan, you will usually be blacklisted very easily by Google, which will ask the tool to complete a captcha.
When you search on Google using custom requests (Google Dorks), you get very easily blacklisted. So Google shows up a page where you have to complete a captcha to continue. As soon as the captcha is completed, Google create a cookie named "GOOGLE_ABUSE_EXEMPTION" which is used to whitelist your browser and IP address for some minutes. This temporary whitelist is enough to let you gather a lot of information from many sources. So I decided to add a simple user manipulation to bypass this bot detection. [...] So I'll just try make requests and wait until I get a 503 error, which means I got blacklisted. Then I ask the user to follow an URL to manually complete the captcha and copy the whitelist token to paste it in the CLI. The tool is now able to continue to scan!

How to handle captcha

  • Follow the URL
  • Complete the captcha if needed
  • Open the dev tool (F12 on most browsers)
  • Go to Storage, then Cookies
  • Copy the value of the GOOGLE_ABUSE_EXEMPTION cookie and simply paste it in the CLI

Troubleshooting

The cookie should be created after you complete the captcha. If there's no captcha and GOOGLE_ABUSE_EXEMPTIONcookie, try pressing F5 to refresh the page. The cookie should've been created. If refreshing the page does not help, change the query to something different (change the number or add text). Google will not necessarily ask you to complete a captcha if your request is the exact same as the previous one, because it'll usually be cached.

Custom formatting

Sometimes the phone number has footprints but is used with a different formatting. This is a problem because for example if we search for "+15417543010", we'll not find web pages that write it that way : "(541) 754–3010". So the tool use a (optional) custom formatting given by the user to find further and more accurate results. To use this feature properly and make the results more valuable, try to use a format that someone of the number' country would usually use to share the phone number online. For example, French people usually write numbers that way online : 06.20.30.40.50, 06 20 30 40 50.

License

This tool is licensed under the GNU General Public License v3.0.
FOSSA Status

domingo, 29 de abril de 2018

Conoce nuestra herramienta de hacking web WebHackSHL

SecHackLabs 
WebHackSHL es una herramienta de código abierto para el análisis de vulnerabilidades y recopilación de información de sitios web y servidores. Esta se basa en la recolección de scripts en python2, ruby , perl y otras herramientas conocidas (como son sqlmap, nmap, nikto, whatweb, etc.), con el propósito general de hacer accesibles las opciones de estas poderosas herramientas a usuarios que no tengan mucha experiencia en el manejo de las mismas. 

WebHackSHL contiene scripts propios, creados por el equipo de Security Hack Labs, junto a otros scripts y programas que tienen las mejores calificaciones y resultados en cada área. La herramienta esta disponible para descarga aquí y se distribuye bajo la licencia GPLv3.

WebHackSHL esta diseñada para operar correctamente en sistemas GNU/Linux Debian o GNU/Linux  ArchLinux y basados en los mismos. WebHackSHL esta en idioma español, lo que facilita el uso de dicha herramienta y actualmente cuenta con 6 apartados en los cuales ofrece diferentes opciones. También existe una version de la herramienta para Android, puedes leer este artículo.
Ayuda:

~$ python2 webhackshl.py -h
Actualizar la herramienta:
~$ python2 webhackshl.py -u 
Uso general:
~$ python2 webhackshl.py
 
WebHack


1) Buscar URLs vulnerables a SQLi, LFI, RCE, XSS. Para realizar esta función, WebHackSHL hace uso de una de las herramientas diseñadas por nosotros llamada sqlitest. Lo que hace básicamente este script es tomar los parámetros que el usuario le pase por la linea de comandos entre los cuales están: Un dominio, un dork y un tipo de test que desee hacer. Aquí una demostración sobre como funciona esta opción.


2) Realizar SQLi a una web vulnerable. Con la opción anterior podemos obtener sitios webs vulnerables a este tipo de ataque, así que vamos a usar uno de los sitios vulnerables que recopilamos anteriormente para hacer una pequeña prueba (Aquí realice la inyección antes para no extender el vídeo, pero todo funciona correctamente).



3) Realizar un escaneo completo a un host, enumerar DNS, Bypassear Cloudflare y más. En este apartado nos encargamos de recolectar la mayor cantidad de información posible sobre nuestro objetivo, usando herramientas como nmap y whatweb.



4) Realizar pruebas de penetración web y análisis de vulnerabilidades. Esta opción nos brinda la oportunidad de realizar el escaneo directo hacia un tipo de CMS especifico, en este caso Joomla o WordPress. Más adelante añadiremos soporte a otros CMS.

5) Buscar el panel admin de un sitio web. Ya luego de haber obtenido las credenciales usando los métodos anteriores, el siguiente paso es encontrar en donde loguearnos dentro de dicha web, para ello esta esta opción que usa uno de nuestros scripts para realizar el escaneo.


6) Ataques a contraseñas y hashing. La finalidad de esta opción es realizar la identificación de tipos de hash y ayudar a la desencriptación mostrando enlaces hacia uno de los mejores sitios como es hashkiller. Adicionalmente existe un link donde hemos recopilado los mejores diccionarios para ataques de bruteforce, que serán implementados próximamente en WebHackSHL.

7) Realizar inyección Server Side template Injection (SSTI) a un sitio web vulnerable. Esta opción sirve para explotar los servidores vulnerables a SSTI, puedes leer este artículo para informarte.

Cabe aclarar que las demostraciones hechas en este tutorial fueron las mas sencillas y solo fue para hacer la presentación de esta herramienta, WebHackSHL contiene muchísimas mas opciones que podrás usar libremente. La herramienta solo esta hecha con fines educativos, cualquier daño realizado con la misma es responsabilidad del usuario.

Síguenos en Facebook, Twitter, unete a nuestra charla en Riot, únete a IRC o únete a Telegram y no olvides compartirnos en las redes sociales. También puede hacernos una donación o comprar nuestros servicios.

viernes, 23 de marzo de 2018

txtool/web pentesting tool



txtool is made to help you for easly pentesting in termux,
build on termux and only available for termux.

installation steps

$ git clone https://github.com/kuburan/txtool.git
$ cd txtool
$ apt install python2
$ ./install.py
Done. type txtool to launch this tool.

Screenshot







 Screenshot



Screenshot